@@ -12,7 +12,7 @@ from beziers.path.representations.fontparts import FontParts
 
 __author__ = """Simon Cozens"""
 __email__ = "simon@simon-cozens.org"
-__version__ = "__version__ = '0.6.1'"
+__version__ = "__version__ = '0.6.2'"
 
 
 def categorize_glyph(font, glyphname):
@@ -240,7 +240,7 @@ def bin_dictionary(d, bincount=5):
     justvalues = d.values()
     if bincount > len(d.keys()):
         bincount = len(d.keys())
-    clusters = ckmeans(justvalues, bincount)
+    clusters = ckmeans(list(justvalues), bincount)
     binned = []
     for c in clusters:
         thiscluster = []
